==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkPoints.java <==
// java wrapper for vtkPoints object
//

package vtk;
import vtk.*;

public class vtkPoints extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Allocate_2(int id0,int id1);
  public int Allocate(int id0,int id1)
    { return Allocate_2(id0,id1); }

  private native void Initialize_3();
  public void Initialize()
    { Initialize_3(); }

  private native void SetData_4(vtkDataArray id0);
  public void SetData(vtkDataArray id0)
    { SetData_4(id0); }

  private native long GetData_5();
  public vtkDataArray GetData() {
    long temp = GetData_5();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetDataType_6();
  public int GetDataType()
    { return GetDataType_6(); }

  private native void SetDataType_7(int id0);
  public void SetDataType(int id0)
    { SetDataType_7(id0); }

  private native void SetDataTypeToBit_8();
  public void SetDataTypeToBit()
    { SetDataTypeToBit_8(); }

  private native void SetDataTypeToChar_9();
  public void SetDataTypeToChar()
    { SetDataTypeToChar_9(); }

  private native void SetDataTypeToUnsignedChar_10();
  public void SetDataTypeToUnsignedChar()
    { SetDataTypeToUnsignedChar_10(); }

  private native void SetDataTypeToShort_11();
  public void SetDataTypeToShort()
    { SetDataTypeToShort_11(); }

  private native void SetDataTypeToUnsignedShort_12();
  public void SetDataTypeToUnsignedShort()
    { SetDataTypeToUnsignedShort_12(); }

  private native void SetDataTypeToInt_13();
  public void SetDataTypeToInt()
    { SetDataTypeToInt_13(); }

  private native void SetDataTypeToUnsignedInt_14();
  public void SetDataTypeToUnsignedInt()
    { SetDataTypeToUnsignedInt_14(); }

  private native void SetDataTypeToLong_15();
  public void SetDataTypeToLong()
    { SetDataTypeToLong_15(); }

  private native void SetDataTypeToUnsignedLong_16();
  public void SetDataTypeToUnsignedLong()
    { SetDataTypeToUnsignedLong_16(); }

  private native void SetDataTypeToFloat_17();
  public void SetDataTypeToFloat()
    { SetDataTypeToFloat_17(); }

  private native void SetDataTypeToDouble_18();
  public void SetDataTypeToDouble()
    { SetDataTypeToDouble_18(); }

  private native void Squeeze_19();
  public void Squeeze()
    { Squeeze_19(); }

  private native void Reset_20();
  public void Reset()
    { Reset_20(); }

  private native void DeepCopy_21(vtkPoints id0);
  public void DeepCopy(vtkPoints id0)
    { DeepCopy_21(id0); }

  private native void ShallowCopy_22(vtkPoints id0);
  public void ShallowCopy(vtkPoints id0)
    { ShallowCopy_22(id0); }

  private native int GetActualMemorySize_23();
  public int GetActualMemorySize()
    { return GetActualMemorySize_23(); }

  private native int GetNumberOfPoints_24();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_24(); }

  private native double[] GetPoint_25(int id0);
  public double[] GetPoint(int id0)
    { return GetPoint_25(id0); }

  private native void GetPoint_26(int id0,double id1[]);
  public void GetPoint(int id0,double id1[])
    { GetPoint_26(id0,id1); }

  private native void SetPoint_27(int id0,double id1[]);
  public void SetPoint(int id0,double id1[])
    { SetPoint_27(id0,id1); }

  private native void SetPoint_28(int id0,double id1,double id2,double id3);
  public void SetPoint(int id0,double id1,double id2,double id3)
    { SetPoint_28(id0,id1,id2,id3); }

  private native void InsertPoint_29(int id0,double id1[]);
  public void InsertPoint(int id0,double id1[])
    { InsertPoint_29(id0,id1); }

  private native void InsertPoint_30(int id0,double id1,double id2,double id3);
  public void InsertPoint(int id0,double id1,double id2,double id3)
    { InsertPoint_30(id0,id1,id2,id3); }

  private native void InsertPoints_31(vtkIdList id0,vtkIdList id1,vtkPoints id2);
  public void InsertPoints(vtkIdList id0,vtkIdList id1,vtkPoints id2)
    { InsertPoints_31(id0,id1,id2); }

  private native void InsertPoints_32(int id0,int id1,int id2,vtkPoints id3);
  public void InsertPoints(int id0,int id1,int id2,vtkPoints id3)
    { InsertPoints_32(id0,id1,id2,id3); }

  private native int InsertNextPoint_33(double id0[]);
  public int InsertNextPoint(double id0[])
    { return InsertNextPoint_33(id0); }

  private native int InsertNextPoint_34(double id0,double id1,double id2);
  public int InsertNextPoint(double id0,double id1,double id2)
    { return InsertNextPoint_34(id0,id1,id2); }

  private native void SetNumberOfPoints_35(int id0);
  public void SetNumberOfPoints(int id0)
    { SetNumberOfPoints_35(id0); }

  private native int Resize_36(int id0);
  public int Resize(int id0)
    { return Resize_36(id0); }

  private native void GetPoints_37(vtkIdList id0,vtkPoints id1);
  public void GetPoints(vtkIdList id0,vtkPoints id1)
    { GetPoints_37(id0,id1); }

  private native void ComputeBounds_38();
  public void ComputeBounds()
    { ComputeBounds_38(); }

  private native double[] GetBounds_39();
  public double[] GetBounds()
    { return GetBounds_39(); }

  private native void GetBounds_40(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_40(id0); }

  private native int GetMTime_41();
  public int GetMTime()
    { return GetMTime_41(); }

  public vtkPoints() { super(); }

  public vtkPoints(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkPoints.java <==
// java wrapper for vtkPoints object
//

package vtk;
import vtk.*;

public class vtkPoints extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int Allocate_2(int id0,int id1);
  public int Allocate(int id0,int id1)
    { return Allocate_2(id0,id1); }

  private native void Initialize_3();
  public void Initialize()
    { Initialize_3(); }

  private native void SetData_4(vtkDataArray id0);
  public void SetData(vtkDataArray id0)
    { SetData_4(id0); }

  private native long GetData_5();
  public vtkDataArray GetData() {
    long temp = GetData_5();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetDataType_6();
  public int GetDataType()
    { return GetDataType_6(); }

  private native void SetDataType_7(int id0);
  public void SetDataType(int id0)
    { SetDataType_7(id0); }

  private native void SetDataTypeToBit_8();
  public void SetDataTypeToBit()
    { SetDataTypeToBit_8(); }

  private native void SetDataTypeToChar_9();
  public void SetDataTypeToChar()
    { SetDataTypeToChar_9(); }

  private native void SetDataTypeToUnsignedChar_10();
  public void SetDataTypeToUnsignedChar()
    { SetDataTypeToUnsignedChar_10(); }

  private native void SetDataTypeToShort_11();
  public void SetDataTypeToShort()
    { SetDataTypeToShort_11(); }

  private native void SetDataTypeToUnsignedShort_12();
  public void SetDataTypeToUnsignedShort()
    { SetDataTypeToUnsignedShort_12(); }

  private native void SetDataTypeToInt_13();
  public void SetDataTypeToInt()
    { SetDataTypeToInt_13(); }

  private native void SetDataTypeToUnsignedInt_14();
  public void SetDataTypeToUnsignedInt()
    { SetDataTypeToUnsignedInt_14(); }

  private native void SetDataTypeToLong_15();
  public void SetDataTypeToLong()
    { SetDataTypeToLong_15(); }

  private native void SetDataTypeToUnsignedLong_16();
  public void SetDataTypeToUnsignedLong()
    { SetDataTypeToUnsignedLong_16(); }

  private native void SetDataTypeToFloat_17();
  public void SetDataTypeToFloat()
    { SetDataTypeToFloat_17(); }

  private native void SetDataTypeToDouble_18();
  public void SetDataTypeToDouble()
    { SetDataTypeToDouble_18(); }

  private native void Squeeze_19();
  public void Squeeze()
    { Squeeze_19(); }

  private native void Reset_20();
  public void Reset()
    { Reset_20(); }

  private native void DeepCopy_21(vtkPoints id0);
  public void DeepCopy(vtkPoints id0)
    { DeepCopy_21(id0); }

  private native void ShallowCopy_22(vtkPoints id0);
  public void ShallowCopy(vtkPoints id0)
    { ShallowCopy_22(id0); }

  private native int GetActualMemorySize_23();
  public int GetActualMemorySize()
    { return GetActualMemorySize_23(); }

  private native int GetNumberOfPoints_24();
  public int GetNumberOfPoints()
    { return GetNumberOfPoints_24(); }

  private native double[] GetPoint_25(int id0);
  public double[] GetPoint(int id0)
    { return GetPoint_25(id0); }

  private native void GetPoint_26(int id0,double id1[]);
  public void GetPoint(int id0,double id1[])
    { GetPoint_26(id0,id1); }

  private native void SetPoint_27(int id0,double id1[]);
  public void SetPoint(int id0,double id1[])
    { SetPoint_27(id0,id1); }

  private native void SetPoint_28(int id0,double id1,double id2,double id3);
  public void SetPoint(int id0,double id1,double id2,double id3)
    { SetPoint_28(id0,id1,id2,id3); }

  private native void InsertPoint_29(int id0,double id1[]);
  public void InsertPoint(int id0,double id1[])
    { InsertPoint_29(id0,id1); }

  private native void InsertPoint_30(int id0,double id1,double id2,double id3);
  public void InsertPoint(int id0,double id1,double id2,double id3)
    { InsertPoint_30(id0,id1,id2,id3); }

  private native void InsertPoints_31(vtkIdList id0,vtkIdList id1,vtkPoints id2);
  public void InsertPoints(vtkIdList id0,vtkIdList id1,vtkPoints id2)
    { InsertPoints_31(id0,id1,id2); }

  private native void InsertPoints_32(int id0,int id1,int id2,vtkPoints id3);
  public void InsertPoints(int id0,int id1,int id2,vtkPoints id3)
    { InsertPoints_32(id0,id1,id2,id3); }

  private native int InsertNextPoint_33(double id0[]);
  public int InsertNextPoint(double id0[])
    { return InsertNextPoint_33(id0); }

  private native int InsertNextPoint_34(double id0,double id1,double id2);
  public int InsertNextPoint(double id0,double id1,double id2)
    { return InsertNextPoint_34(id0,id1,id2); }

  private native void SetNumberOfPoints_35(int id0);
  public void SetNumberOfPoints(int id0)
    { SetNumberOfPoints_35(id0); }

  private native int Resize_36(int id0);
  public int Resize(int id0)
    { return Resize_36(id0); }

  private native void GetPoints_37(vtkIdList id0,vtkPoints id1);
  public void GetPoints(vtkIdList id0,vtkPoints id1)
    { GetPoints_37(id0,id1); }

  private native void ComputeBounds_38();
  public void ComputeBounds()
    { ComputeBounds_38(); }

  private native double[] GetBounds_39();
  public double[] GetBounds()
    { return GetBounds_39(); }

  private native void GetBounds_40(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_40(id0); }

  private native int GetMTime_41();
  public int GetMTime()
    { return GetMTime_41(); }

  public vtkPoints() { super(); }

  public vtkPoints(long id) { super(id); }
  public native long   VTKInit();

}
